==> wiki3_5_6.zip: wiki3_5_6/plugin/core/EditPage.pm <==
###############################################################################
# 
# ڡԽץ饰
# 
###############################################################################
package plugin::core::EditPage;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $format   = $wiki->get_edit_format();
	my $content  = $cgi->param("content");
	my $sage     = $cgi->param("sage");
	my $template = $cgi->param("template");
	my $artno    = $cgi->param("artno");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();

	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ");
	}
	if($pagename =~ /\[|\]/){
		return $wiki->error("ڡ̾˥֥饱åȤޤ뤳ȤϤǤޤ");
	}
	if($pagename =~ /:/){
		return $wiki->error("ڡ̾˥ޤ뤳ȤϤǤޤ");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#--------------------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
		#my $save_content = $content;
		my $mode = $wiki->get_edit_format();
		my $save_content = $wiki->convert_to_fswiki($content,$mode);

		# ѡԽξ
		if($artno ne ""){
			$save_content = &make_save_source($wiki->get_page($pagename),$save_content,$artno,$wiki);
		}
		# FrontPageϺԲ
		if($pagename eq $wiki->config("frontpage") && $save_content eq ""){
			$buf = "<b>".&Util::escapeHTML($wiki->config("frontpage"))."Ϻ뤳ȤϤǤޤ</b>\n";

		# ʳξϽ¹Ԥƥåֵ
		} else {
			$wiki->save_page($pagename,$save_content,$sage);
			
			if($content ne ""){
				$wiki->redirect($pagename);
			} else {
				if($artno eq ""){
					$wiki->set_title($pagename."ޤ");
					return $cgi->escapeHTML($pagename)."ޤ";
				} else {
					$wiki->set_title($pagename."ΥѡȤޤ");
					return $cgi->escapeHTML($pagename)."ΥѡȤޤ";
				}
			}
		}
	#--------------------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq $wiki->config("frontpage") && $artno eq ""){
				$buf = $buf."<b>".&Util::escapeHTML($wiki->config("frontpage"))."Ϻ뤳ȤϤǤޤ󡣡</b>";
			} else {
				if($artno eq ""){
					$buf = $buf."<b>ʥڡƤ϶ǤȤΥڡϺޤ</b>";
				} else {
					$buf = $buf."<b>ʥڡƤ϶ǤȤΥѡȤϺޤ</b>";
				}
			}
		}
		$content = $wiki->convert_to_fswiki($content,$format);
		$buf = $buf."<br>".$wiki->process_wiki($content);

	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
		if($artno eq ""){
			$content = $wiki->get_page($pagename);
		} else {
			$content = &read_by_part($wiki->get_page($pagename),$artno);
		}
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#--------------------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."Խ",1);

	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/editform.tmpl",
                                   die_on_bad_params => 0);

	$tmpl->param({SCRIPT_NAME   => $wiki->config('script_name'),
				  PAGE_NAME     => $pagename,
				  CONTENT       => $wiki->convert_from_fswiki($content,$format),
				  LAST_MODIFIED => $time,
				  ACTION        => 'EDIT',
				  EXISTS_PAGE   => $wiki->page_exists($pagename),
				  SAGE          => $sage});
	
	if($artno ne ""){
		$tmpl->param(OPTIONAL_PARAMS=>[{NAME=>'artno',VALUE=>$artno}]);
	}

	$buf .= $tmpl->output();

	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

#==============================================================================
# ѡԽξԽʬμФ
#==============================================================================
sub read_by_part {
	my $page  = shift;
	my $num   = shift;
	my $count = 0;
	my $buf   = "";
	my $level = 0;
	my $flag  = 0;
	foreach my $line (split(/\n/,$page)){
		if($line=~/^(!{1,3})/){
			if($flag==1 && $level<=length($1)){
				last;
			}
			if($count==$num){
				$flag  = 1;
				$level = length($1);
			}
			$count++;
		}
		if($flag==1){
			$buf .= $line."\n";
		}
	}
	return $buf;
}

#==============================================================================
# ѡԽξ¸ѥκ
#==============================================================================
sub make_save_source {
	my $org   = shift;
	my $edit  = shift;
	my $num   = shift;
	my $wiki  = shift;
	my $count = 0;
	my $buf   = "";
	my $level = "";
	my $flag  = "";
	foreach my $line (split(/\n/,$org)){
		if($line=~/^(!{1,3})/){
			if($flag==1 && $level<=length($1)){
				$flag = 0;
			}
			if($count==$num){
				$flag  = 1;
				$level = length($1);
				$buf .= $edit;
				# Ǹ夬ԤǤʤԤɲáʼΥȤäĤƤޤ
				$buf .= "\n" unless($edit =~ /\n$/);
			}
			$count++;
		}
		if($flag==0){
			$buf .= "$line\n";
		}
	}
	return $buf;
}

#==============================================================================
# ڡɽΥեå᥽å
# Խץ˥塼ͭˤޤ
#==============================================================================
sub hook {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $login    = $wiki->get_login_info();
	
	# Խ˥塼
	if($wiki->can_modify_page($pagename)){
		$wiki->add_menu("Խ",$wiki->config('script_name').
		                "?action=EDIT&amp;page=".&Util::url_encode($pagename));
	}
}

1;

==> wiki3_6_0.zip: wiki3_6_0/plugin/core/EditPage.pm <==
###############################################################################
# 
# ڡԽץ饰
# 
###############################################################################
package plugin::core::EditPage;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $format   = $wiki->get_edit_format();
	my $content  = $cgi->param("content");
	my $sage     = $cgi->param("sage");
	my $template = $cgi->param("template");
	my $artno    = $cgi->param("artno");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();

	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ");
	}
	if($pagename =~ /([\|\[\]])|^:|([^:]:[^:])/){
		return $wiki->error("ڡ̾˻ѤǤʤʸޤޤƤޤ");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#--------------------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
		#my $save_content = $content;
		my $mode = $wiki->get_edit_format();
		my $save_content = $wiki->convert_to_fswiki($content,$mode);

		# ѡԽξ
		if($artno ne ""){
			$save_content = &make_save_source($wiki->get_page($pagename),$save_content,$artno,$wiki);
		}
		# FrontPageϺԲ
		if($pagename eq $wiki->config("frontpage") && $save_content eq ""){
			$buf = "<b>".&Util::escapeHTML($wiki->config("frontpage"))."Ϻ뤳ȤϤǤޤ</b>\n";

		# ʳξϽ¹Ԥƥåֵ
		} else {
			$wiki->save_page($pagename,$save_content,$sage);
			
			if($content ne ""){
				$wiki->redirect($pagename);
			} else {
				if($artno eq ""){
					$wiki->set_title($pagename."ޤ");
					return $cgi->escapeHTML($pagename)."ޤ";
				} else {
					$wiki->set_title($pagename."ΥѡȤޤ");
					return $cgi->escapeHTML($pagename)."ΥѡȤޤ";
				}
			}
		}
	#--------------------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq $wiki->config("frontpage") && $artno eq ""){
				$buf = $buf."<b>".&Util::escapeHTML($wiki->config("frontpage"))."Ϻ뤳ȤϤǤޤ󡣡</b>";
			} else {
				if($artno eq ""){
					$buf = $buf."<b>ʥڡƤ϶ǤȤΥڡϺޤ</b>";
				} else {
					$buf = $buf."<b>ʥڡƤ϶ǤȤΥѡȤϺޤ</b>";
				}
			}
		}
		$content = $wiki->convert_to_fswiki($content,$format);
		$buf = $buf."<br>".$wiki->process_wiki($content);

	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
		if($artno eq ""){
			$content = $wiki->get_page($pagename);
		} else {
			$content = &read_by_part($wiki->get_page($pagename),$artno);
		}
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#--------------------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."Խ",1);

	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/editform.tmpl",
                                   die_on_bad_params => 0);

	$tmpl->param({SCRIPT_NAME   => $wiki->config('script_name'),
				  PAGE_NAME     => $pagename,
				  CONTENT       => $wiki->convert_from_fswiki($content,$format),
				  LAST_MODIFIED => $time,
				  ACTION        => 'EDIT',
				  EXISTS_PAGE   => $wiki->page_exists($pagename),
				  SAGE          => $sage});
	
	if($artno ne ""){
		$tmpl->param(OPTIONAL_PARAMS=>[{NAME=>'artno',VALUE=>$artno}]);
	}

	$buf .= $tmpl->output();

	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

#==============================================================================
# ѡԽξԽʬμФ
#==============================================================================
sub read_by_part {
	my $page  = shift;
	my $num   = shift;
	my $count = 0;
	my $buf   = "";
	my $level = 0;
	my $flag  = 0;
	foreach my $line (split(/\n/,$page)){
		if($line=~/^(!{1,3})/){
			if($flag==1 && $level<=length($1)){
				last;
			}
			if($count==$num){
				$flag  = 1;
				$level = length($1);
			}
			$count++;
		}
		if($flag==1){
			$buf .= $line."\n";
		}
	}
	return $buf;
}

#==============================================================================
# ѡԽξ¸ѥκ
#==============================================================================
sub make_save_source {
	my $org   = shift;
	my $edit  = shift;
	my $num   = shift;
	my $wiki  = shift;
	my $count = 0;
	my $buf   = "";
	my $level = "";
	my $flag  = "";
	foreach my $line (split(/\n/,$org)){
		if($line=~/^(!{1,3})/){
			if($flag==1 && $level<=length($1)){
				$flag = 0;
			}
			if($count==$num){
				$flag  = 1;
				$level = length($1);
				$buf .= $edit;
				# Ǹ夬ԤǤʤԤɲáʼΥȤäĤƤޤ
				$buf .= "\n" unless($edit =~ /\n$/);
			}
			$count++;
		}
		if($flag==0){
			$buf .= "$line\n";
		}
	}
	return $buf;
}

#==============================================================================
# ڡɽΥեå᥽å
# Խץ˥塼ͭˤޤ
#==============================================================================
sub hook {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $login    = $wiki->get_login_info();
	
	# Խ˥塼
	if($wiki->can_modify_page($pagename)){
		$wiki->add_menu("Խ",$wiki->config('script_name').
		                "?action=EDIT&amp;page=".&Util::url_encode($pagename));
	}
}

1;
